# CLI Reference

The Agent Starter Pack provides a command-line interface (CLI) to create and setup Generative AI Agent templates in Google Cloud. 

## Available Commands

- [`create`](create.md) - Create a new generative AI application project
- [`setup-cicd`](setup_cicd.md) - Set up CI/CD pipeline for your project
- [`enhance`](enhance.md) - Add agent-starter-pack capabilities to existing projects without creating a new directory
- [`extract`](extract.md) - Create a minimal, shareable agent by removing deployment scaffolding
- [`upgrade`](upgrade.md) - Upgrade project to the latest agent-starter-pack version
- [`list`](list.md) - List available agents and templates
- [`register-gemini-enterprise`](register_gemini_enterprise.md) - Register a deployed Agent Engine to Gemini Enterprise

For detailed usage instructions, click on the command links above.
